'use strict';

angular.module('walStroomApp', [
  'ngCookies',
  'ngTouch',
  'ngResource',
  'ngDialog',
  'ngCordova',
  'ngSanitize',
  'pascalprecht.translate',
  'leaflet-directive'

]).constant('walStroomSettings', {
    clientId: 'abc123',
    clientSecret: 'ssh-secret',
    accessTokenKey: 'accessToken',
    basicAuthHashKey: 'basicAuthHash',
    services: {
        token: {
           url: '/token',
           appId: 'The App Id',
           appSecret: 'The App Secret',
           appVersion: '1.0',
           appScope: 'Api'
        },
        parking: {
            url: '/parking/active'
        },
        vehicle: {
            url: '/account/vehicles'
        },
        parkingActionHistory: {
            url: '/parking/history'
        },
        invoiceHistory: {
            url: '/account/invoices'
        },
        searchZones: {
            url: '/search/zones'
        },
        searchZoneGroups: {
            url: '/search/zonegroups'
        },
        searchLocationGroups: {
            url: '/search/locations'
        },
        reminders: {
            url: '/account/reminders'
        },
        boats:{
            url: '/account/boats'
        },
        profile:{
            url: '/account/profile'
        }
    }
}).constant('geolocation_msgs', {
    'errors.location.unsupportedBrowser':'Browser does not support location services',
    'errors.location.permissionDenied':'You have rejected access to your location',
    'errors.location.positionUnavailable':'Unable to determine your location',
    'errors.location.timeout':'Service timeout has been reached'
})



.config(function ($httpProvider, $translateProvider) {

        $httpProvider.interceptors.push('BasicAuthInterceptor');


        $translateProvider.translations('en', {
            version: '{{ VERSION }}',
            builddate: '{{ BUILD_DATE }}',
            Empty: '',
            Saturday: 'Saturday',
            Sunday: 'Sunday',
            Monday: 'Monday',
            Tuesday: 'Tuesday',
            Wednesday: 'Wednesday',
            Thursday: 'Thursday',
            Friday: 'Friday',
            boatLength: 'Length',
            boatDepth: 'Depth',
            boatDisplacement: 'Displacement',
            boatENInumber: 'ENI number',
            MenuLabelFaq: 'FAQ',
            MenuTitleFaq: 'FAQ',
            NotBeschikbaar: 'Not Available',
            Beschikbaar: 'Available',
            UserName: 'Username',
            UserNameRequired: 'Username is required',
            Password: 'Password',
            PasswordRequired: 'Password is required',
            MenuLabelHowTo: 'How does it work?',
            MenuTitleHowTo: 'How does it work?',
            MenuLabelAbout: 'About Walstroom',
            MenuTitleAbout: 'About Walstroom',
            MenuLabelNotifications: 'Notifications',
            MenuTitleNotifications: 'Notifications',
            MenuLabelShips: 'Vessels',
            MenuTitleShips: 'Vessels',
            KastNumber: 'Box {{kastNumber}}',
            ConnectieNumber: 'Connection {{connectieNumber}}',
            Connections: 'Connection',
            SearchKastNumber: 'Search for box number',
            LostPasswordExplanation: 'SMS  \'wp login\' to 4111. You will receive a sms with your login credentials (€0,25 per sms)',
            Save: 'Save',
            OK: ' OK',
            Cancel: ' Cancel',
            ShowCost: 'View costs',
            MenuLabelActions: 'Actions',
            MenuTitleActions: 'Actions',
            SpaceAvailable: '{{numberOfSpace}} available',
            TechnicalErrorExplanation: 'Please try again later.',
            TechnicalError: 'Oops, something went wrong',
            LostPassword: 'Forgot Password?',
            Tarief: 'Tariff',
            NoAccount: 'Don’t have an account?',
            TapHere: 'Tap here to register one.',
            WalStroom: 'Park-line Walstroom',
            AboutWalStroom: 'About Park-line Walstroom',
            TransactionStopWalstroom: 'Action Stopped',
            TransactionStopFreshWater: 'Action Stopped',
            TransactionStopExplanation: 'Do you want to view the costs of this action?',
            LoggedInAs: 'Logged in as: {{userName}}',
            MenuTitleSignout: 'Log Out',
            MenuLabelHistory: 'History',
            MenuTitleHistory: 'History',
            LostPasswordPreLink: 'Or got to the ',
            LostPasswordLink: 'forgot password',
            LostPasswordPostLink: ' page.',
            Stop: 'Stop',
            Start: 'Start',
            Today: 'Today',
            dag: 'day',
            uur: 'hour',
            min: 'min',
            Usage: 'Usage',
            Costs: 'Costs',
            StartTariff:'Transaction costs',


        });
        $translateProvider.translations('nl', {
            version: '{{ VERSION }}',
            builddate: '{{ BUILD_DATE }}',
            Empty: '',
            Saturday: 'Zaterdag',
            Sunday: 'Zondag',
            Monday: 'Maandag',
            Tuesday: 'Dinsdag',
            Wednesday: 'Woensdag',
            Thursday: 'Donderdag',
            Friday: 'Vrijdag',
            boatLength: 'Lengte',
            boatDepth: 'Diepte',
            boatDisplacement: 'Waterverplaatsing',
            boatENInumber: 'ENI nummer',
            MenuLabelFaq: 'Veel gestelde vragen',
            MenuTitleFaq: 'Veel gestelde vragen',
            MenuLabelActions: 'Acties',
            MenuTitleActions: 'Acties',
            MenuLabelNotifications: 'Notificaties',
            MenuTitleNotifications: 'Notificaties',
            MenuLabelShips: 'Vaartuigen',
            MenuTitleShips: 'Vaartuigen',
            MenuLabelHistory: 'Geschiedenis',
            MenuTitleHistory: 'Geschiedenis',
            MenuLabelAbout: 'Over Walstroom',
            MenuTitleAbout: 'Over Walstroom',
            MenuLabelHowTo: 'Hoe werkt het?',
            MenuTitleHowTo: 'Hoe werkt het?',
            MenuTitleSignout: 'Uitloggen',
            SpaceAvailable: '{{numberOfSpace}} beschikbaar',
            KastNumber: 'Kast {{kastNumber}}',
            ConnectieNumber: 'Connectie {{connectieNumber}}',
            Connections: 'Connecties',
            SearchKastNumber: 'Zoek op kastnummer',
            Tarief: 'Tarief',
            Beschikbaar: 'Beschikbaar',
            NotBeschikbaar: 'Niet Beschikbaar',
            LostPassword: 'Wachtwoord Vergeten?',
            NoAccount: 'Heeft u nog geen account?',
            TapHere: 'Klik dan hier om er een aan te maken.',
            WalStroom: 'Park-line Walstroom',
            AboutWalStroom: 'Over Park-line Walstroom',
            UserName: 'Gebruikersnaam',
            UserNameRequired: 'Gebruikersnaam is verplicht',
            Password: 'Wachtwoord',
            PasswordRequired: 'Wachtwoord is verplicht',
            LostPasswordExplanation: 'Stuur een sms naar 4111 met de boodschap: \'wp login\'. U zult een sms ontvangen met daarin uw wachtwoord. (€0,25 p.o.b.)',
            LostPasswordPreLink: 'Of ga naar de ',
            LostPasswordLink: 'wachtwoord vergeten',
            LostPasswordPostLink: ' pagina.',
            Save: 'Opslaan',
            OK: ' OK',
            Cancel: ' Annuleer',
            ShowCost: 'Bekijk kosten',
            TransactionStopWalstroom: 'Stroomlevering is gestopt',
            TransactionStopFreshWater: 'Waterlevering is gestopt',
            TransactionStopExplanation: 'Wilt u nu de gemaakte kosten bekijken?',
            TechnicalError: 'Oeps er ging iets fout',
            TechnicalErrorExplanation: 'Probeer het later nog eens!',
            LoggedInAs: 'Ingelogd als: {{userName}}',
            Stop: 'Stop',
            Start: 'Start',
            Today: 'Vandaag',
            dag: 'dag',
            uur: 'uur',
            min: 'min',
            Usage: 'Verbruik',
            Costs: 'Kosten',
            StartTariff:'Transactie kosten',
        });
        $translateProvider.fallbackLanguage('nl');
        $translateProvider.registerAvailableLanguageKeys(['en', 'nl']);
        $translateProvider.determinePreferredLanguage();
    });
